import type { ServerRow } from '@genesislcap/foundation-comms';
/**
 * Represents an individual service with basic information necessary for status tracking.
 * @public
 */
export interface ServiceItem {
    id: string;
    name: string;
    isWorking: boolean;
}
/**
 * Represents the available types of service status messages.
 * @public
 */
export type ServiceStatusAvailableTypes = 'restored' | 'failed';
/**
 * Parameters for template functions used in service status messaging, providing hooks for restoration and failure handling.
 * @public
 */
export interface ServiceStatusGetTemplateParmas {
    restored: (prefix: string, item: ServiceItem) => any;
    failed: (prefix: string, item: ServiceItem) => any;
}
/**
 * Configuration options for service status, including behavior around automatic closure and timeouts.
 * @public
 */
export interface ServicesStatusConfig {
    autoClose: boolean;
    closeTimeout: number;
    maxMessages: number;
}
/**
 * Extends the basic server row with detailed information specific to a service process, including status, resources, and operational flags.
 * @internal
 */
export interface ServiceServerItem extends ServerRow {
    PROCESS_PORT: number;
    START_TIME: string;
    PROCESS_STATUS: boolean;
    PROCESS_ENABLED: boolean;
    PROCESS_SECURE: boolean;
    PROCESS_STATE_TEXT: string;
    DATADUMP: boolean;
    PROCESS_RESOURCES: string;
    PROCESS_MEM_USAGE: number;
    PROCESS_CPU_USAGE: number;
    PROCESS_NAME: string;
    PROCESS_STATUS_MESSAGE: string;
    LOG_LEVEL: string;
    PROCESS_HOSTNAME: string;
}
/**
 * Type helper for the service status helper text generation.
 * @internal
 */
export type ServiceStatusHelperText = 'title' | 'message';
//# sourceMappingURL=main.types.d.ts.map